# fna_ver.tcl:  Convert version strings.
# RCS Id: $Id: fna_ver.tcl,v 1.0.0.3 1996/07/06 03:52:29 ndanger Alpha $

# fna:ver_version:  Return the version of this file.

proc fna:ver_version {} {
  return [fna:ver_rcs {$Revision: 1.0.0.3 $} {$State: Alpha $}]
}


# fna:ver_rcs:  Convert RCS version and state keywords into my own peculiar
#	brand of version number.
# Invocation:
#   fna:ver_rcs rev state
#     rev	What RCS substitutes for the "Revision" keyword upon
#		checkout.  Do *not* checkout with -kv!
#     state	What RCS substitutes for the "State" keyword upon checkout.
# Description:
#    Use a 4-digit revision number for RCS, according to the following
#    conventions:
#      x.y.0.z		Version x.y, Alpha release z (State = Alpha)
#      x.y.1.z		Version x.y, Beta release z (State = Beta)
#      x.y.2.0		Version x.y, Release (State = Release)
#      x.y.2.z		Version x.y, Patch level z (State = Release)
#    Then fna:ver_rcs will return:
#      X.Y.0.Z		X.YaZ
#      X.Y.1.Z		X.YbZ
#      X.Y.2.Z		X.Y
#    So a typical code fragment might set a variable with a version number
#    in it something like:
#	set version [fna:ver_rcs {$Revision: 1.0.0.3 $} {$State: Alpha $}]
#    The braces are necessary to prevent unwanted variable expansion.
#    Initially just the keywords are given as the arguments; when
#    the file is checked out, the two arguments are filled in appropriately
#    by RCS.

proc fna:ver_rcs {rev state} {
  set rev [lindex $rev 1]
  set rev_vals [split $rev .]
  set rev_mm "[lindex $rev_vals 0].[lindex $rev_vals 1]"
  set rev_mm_lev [lindex $rev_vals 3]
  set state [lindex $state 1]
  set version $rev_mm
  if {$state == "Alpha" || $state == "Beta"} {
    append version [string tolower [string index $state 0]]
    append version $rev_mm_lev
  }
  return $version
}
